@@ -3,7 +3,6 @@
 namespace App\Classes\LDAP\Attribute;
 
 use Illuminate\Support\Arr;
-use Illuminate\Support\Facades\Log;
 
 use App\Classes\LDAP\Attribute;
 
@@ -59,8 +58,6 @@ class Factory
 	public static function create(string $dn,string $attribute,array $values,array $oc=[]): Attribute
 	{
 		$class = Arr::get(self::map,strtolower($attribute),Attribute::class);
-		Log::debug(sprintf('%s:Creating LDAP Attribute [%s] as [%s]',static::LOGKEY,$attribute,$class));
-
 		return new $class($dn,$attribute,$values,$oc);
 	}
 }
\ No newline at end of file
