@@ -2,12 +2,10 @@
 
 namespace App\Classes\LDAP\Attribute;
 
-use Illuminate\Contracts\View\View;
 use Illuminate\Support\Arr;
 use Illuminate\Support\Facades\Cache;
 
 use App\Classes\LDAP\Attribute;
-use App\Ldap\Entry;
 
 /**
  * Represents an attribute whose values are schema related
@@ -53,11 +51,4 @@ abstract class Schema extends Attribute
 			$key,
 			__('No description available, can you help with one?'));
 	}
-
-	public function render(bool $edit=FALSE,bool $old=FALSE,bool $new=FALSE,string $langtag=Entry::TAG_NOTAG,bool $updated=FALSE): View
-	{
-		// @note Schema attributes cannot be edited
-		return view('components.attribute.internal')
-			->with('o',$this);
-	}
 }
\ No newline at end of file
