@@ -6,17 +6,18 @@ use Illuminate\Http\Request;
 use Illuminate\Support\Arr;
 use Illuminate\Support\Collection;
 use Illuminate\Support\Facades\Auth;
+use Illuminate\Support\Facades\Cache;
 use Illuminate\Support\Facades\Crypt;
 use Illuminate\Support\Facades\File;
 use Illuminate\Support\Facades\Log;
 use Illuminate\Support\Facades\Redirect;
+use Illuminate\Support\Facades\Session;
 use LdapRecord\Exceptions\InsufficientAccessException;
 use LdapRecord\LdapRecordException;
 use LdapRecord\Query\ObjectNotFoundException;
 use Nette\NotImplementedException;
 
 use App\Classes\LDAP\Attribute\{Factory,Password};
-use App\Classes\LDAP\Server;
 use App\Classes\LDAP\Import\LDIF as LDIFImport;
 use App\Classes\LDAP\Export\LDIF as LDIFExport;
 use App\Exceptions\Import\{GeneralException,VersionException};
@@ -26,20 +27,9 @@ use App\Ldap\Entry;
 
 class HomeController extends Controller
 {
-	private function bases(): Collection
-	{
-		$base = Server::baseDNs(TRUE) ?: collect();
+	private const LOGKEY = 'CHc';
 
-		return $base->transform(function($item) {
-			return [
-				'title'=>$item->getRdn(),
-				'item'=>$item->getDNSecure(),
-				'lazy'=>TRUE,
-				'icon'=>'fa-fw fas fa-sitemap',
-				'tooltip'=>$item->getDn(),
-			];
-		});
-	}
+	private const INTERNAL_POST = ['_auto_value','_key','_rdn','_rdn_new','_rdn_value','_step','_template','_token','_userpassword_hash'];
 
 	/**
 	 * Create a new object in the LDAP server
@@ -50,30 +40,45 @@ class HomeController extends Controller
 	 */
 	public function entry_add(EntryAddRequest $request): \Illuminate\View\View
 	{
-		if (! old('step',$request->validated('step')))
+		if (! old('_step',$request->validated('_step')))
 			abort(404);
 
 		$key = $this->request_key($request,collect(old()));
 
+		$template = NULL;
 		$o = new Entry;
+		$o->setRDNBase($key['dn']);
 
-		if (count($x=array_filter(old('objectclass',$request->objectclass)))) {
-			$o->objectclass = $x;
+		foreach (collect(old())->except(self::INTERNAL_POST) as $old => $value)
+			$o->{$old} = array_filter($value);
+
+		if (old('_template',$request->validated('template'))) {
+			$template = $o->template(old('_template',$request->validated('template')));
+
+			$o->objectclass = [Entry::TAG_NOTAG=>$template->objectclasses->toArray()];
+
+			foreach ($o->getAvailableAttributes()
+				 ->filter(fn($item)=>$item->names_lc->intersect($template->attributes->keys()->map('strtolower'))->count())
+				 ->sortBy(fn($item)=>Arr::get($template->order,$item->name)) as $ao)
+			{
+				$o->{$ao->name} = [Entry::TAG_NOTAG=>''];
+			}
+
+		} elseif (count($x=collect(old('objectclass',$request->validated('objectclass')))->dot()->filter())) {
+			$o->objectclass = Arr::undot($x);
 
 			// Also add in our required attributes
-			foreach($o->getAvailableAttributes()->filter(fn($item)=>$item->required) as $ao)
+			foreach ($o->getAvailableAttributes()->filter(fn($item)=>$item->is_must) as $ao)
 				$o->{$ao->name} = [Entry::TAG_NOTAG=>''];
-
-			$o->setRDNBase($key['dn']);
 		}
 
-		$step = $request->step ? $request->step+1 : old('step');
+		$step = $request->get('_step') ? $request->get('_step')+1 : old('_step');
 
 		return view('frame')
 			->with('subframe','create')
-			->with('bases',$this->bases())
 			->with('o',$o)
 			->with('step',$step)
+			->with('template',$template)
 			->with('container',old('container',$key['dn']));
 	}
 
@@ -103,21 +108,83 @@ class HomeController extends Controller
 		return $view
 			->with('o',$o)
 			->with('langtag',Entry::TAG_NOTAG)
+			->with('template',NULL)
 			->with('updated',FALSE);
 	}
 
+	public function entry_copy_move(Request $request): \Illuminate\Http\RedirectResponse|\Illuminate\View\View
+	{
+		$from_dn = Crypt::decryptString($request->post('dn'));
+		Log::info(sprintf('%s:Renaming [%s] to [%s]',self::LOGKEY,$from_dn,$request->post('to_dn')));
+
+		$o = clone config('server')->fetch($from_dn);
+
+		if (! $o)
+			return back()
+				->withInput()
+				->with('note',__('DN doesnt exist'));
+
+		$o->setDN($request->post('to_dn'));
+		$o->exists = FALSE;
+
+		// Add the RDN attribute to match the new RDN
+		$rdn = collect(explode(',',$request->post('to_dn')))->first();
+
+		list($attr,$value) = explode('=',$rdn);
+		$o->{$attr} = [Entry::TAG_NOTAG => $o->getObject($attr)->tagValuesOld(Entry::TAG_NOTAG)->push($value)->unique()];
+
+		Log::info(sprintf('%s:Copying [%s] to [%s]',self::LOGKEY,$from_dn,$o->getDN()));
+
+		try {
+			$o->save();
+
+		} catch (LdapRecordException $e) {
+			return Redirect::to('/')
+				->withInput(['_key'=>Crypt::encryptString('*dn|'.$from_dn)])
+				->with('failed',sprintf('%s: %s - %s: %s',
+					__('LDAP Server Error Code'),
+					$e->getDetailedError()?->getErrorCode() ?: $e->getMessage(),
+					$e->getDetailedError()?->getErrorMessage() ?: $e->getFile(),
+					$e->getDetailedError()?->getDiagnosticMessage() ?: $e->getLine(),
+				));
+		}
+
+		if ($request->post('delete') && $request->post('delete') === '1') {
+			Log::info(sprintf('%s:Deleting [%s] after copy',self::LOGKEY,$from_dn));
+
+			$x = $this->entry_delete($request);
+
+			return ($x->getSession()->has('success'))
+				? Redirect::to('/')
+					->withInput(['_key'=>Crypt::encryptString('*dn|'.$o->getDN())])
+					->with('success',__('Entry copied and deleted'))
+				: $x;
+		}
+
+		return Redirect::to('/')
+			->withInput(['_key'=>Crypt::encryptString('*dn|'.$o->getDN())])
+			->with('success',__('Entry copied'));
+	}
+
 	public function entry_create(EntryAddRequest $request): \Illuminate\Http\RedirectResponse
 	{
 		$key = $this->request_key($request,collect(old()));
 
-		$dn = sprintf('%s=%s,%s',$request->rdn,$request->rdn_value,$key['dn']);
+		$dn = sprintf('%s=%s,%s',$request->get('_rdn'),$request->get('_rdn_value'),$key['dn']);
 
 		$o = new Entry;
 		$o->setDn($dn);
 
-		foreach ($request->except(['_token','key','step','rdn','rdn_value','userpassword_hash']) as $key => $value)
+		foreach ($request->except(self::INTERNAL_POST) as $key => $value)
 			$o->{$key} = array_filter($value);
 
+		// We need to process and encrypt the password
+		if ($request->userpassword)
+			$o->userpassword = $this->password(
+				$o->getObject('userpassword'),
+				$request->userpassword,
+				$request->get('_userpassword_hash'));
+
 		try {
 			$o->save();
 
@@ -141,11 +208,17 @@ class HomeController extends Controller
 				->with('failed',sprintf('%s: %s - %s: %s',
 					__('LDAP Server Error Code'),
 					$e->getDetailedError()->getErrorCode(),
-					__($e->getDetailedError()->getErrorMessage()),
+					$e->getDetailedError()->getErrorMessage(),
 					$e->getDetailedError()->getDiagnosticMessage(),
 				));
 		}
 
+		// If there are an _auto_value attributes, we need to invalid those
+		foreach ($request->get('_auto_value',[]) as $attr => $value) {
+			Log::debug(sprintf('%s:Removing auto_value attr [%s]',self::LOGKEY,$attr));
+			Cache::delete($attr.':'.Session::id());
+		}
+
 		return Redirect::to('/')
 			->withFragment($o->getDNSecure());
 	}
@@ -187,7 +260,7 @@ class HomeController extends Controller
 		}
 
 		return Redirect::to('/')
-			->with('success',[sprintf('%s: %s',__('Deleted'),$dn)]);
+			->with('success',sprintf('%s: %s',__('Deleted'),$dn));
 	}
 
 	public function entry_export(Request $request,string $id): \Illuminate\View\View
@@ -211,7 +284,7 @@ class HomeController extends Controller
 	 */
 	public function entry_objectclass_add(Request $request): Collection
 	{
-		$dn = $request->key ? Crypt::decryptString($request->dn) : '';
+		$dn = $request->get('_key') ? Crypt::decryptString($request->dn) : '';
 		$oc = Factory::create($dn,'objectclass',$request->oc);
 
 		$ocs = $oc
@@ -266,43 +339,53 @@ class HomeController extends Controller
 
 		$o = config('server')->fetch($dn);
 
-		foreach ($request->except(['_token','dn','userpassword_hash','userpassword']) as $key => $value)
+		foreach ($request->except(['_token','dn','_userpassword_hash','userpassword']) as $key => $value)
 			$o->{$key} = array_filter($value,fn($item)=>! is_null($item));
 
 		// @todo Need to handle incoming attributes that were modified by MD5Updates Trait (eg: jpegphoto)
 
 		// We need to process and encrypt the password
-		if ($request->userpassword) {
-			$passwords = [];
-			$po = $o->getObject('userpassword');
-			foreach (Arr::dot($request->userpassword) as $dotkey => $value) {
-				// If the password is still the MD5 of the old password, then it hasnt changed
-				if (($old=Arr::get($po,$dotkey)) && ($value === md5($old))) {
-					$passwords[$dotkey] = $value;
-					continue;
-				}
-
-				if ($value) {
-					$type = Arr::get($request->userpassword_hash,$dotkey);
-					$passwords[$dotkey] = Password::hash_id($type)
-						->encode($value);
-				}
-			}
-
-			$o->userpassword = Arr::undot($passwords);
-		}
+		if ($request->userpassword)
+			$o->userpassword = $this->password(
+				$o->getObject('userpassword'),
+				$request->userpassword,
+				$request->get('_userpassword_hash'));
 
 		if (! $o->getDirty())
-			return back()
+			return Redirect::back()
 				->withInput()
 				->with('note',__('No attributes changed'));
 
 		return view('update')
-			->with('bases',$this->bases())
 			->with('dn',$dn)
 			->with('o',$o);
 	}
 
+	public function entry_rename(Request $request): \Illuminate\Http\RedirectResponse|\Illuminate\View\View
+	{
+		$from_dn = Crypt::decryptString($request->post('dn'));
+		Log::info(sprintf('%s:Renaming [%s] to [%s]',self::LOGKEY,$from_dn,$request->post('_rdn_new')));
+
+		$o = config('server')->fetch($from_dn);
+
+		if (! $o)
+			return Redirect::back()
+				->withInput()
+				->with('note',__('DN doesnt exist'));
+
+		try {
+			$o->rename($request->post('_rdn_new'));
+
+		} catch (\Exception $e) {
+			return Redirect::to('/')
+				->with('failed',$e->getMessage());
+		}
+
+		return Redirect::to('/')
+			->withInput(['_key'=>Crypt::encryptString('*dn|'.$o->getDN())])
+			->with('success',sprintf('%s: %s',__('Entry renamed'),$from_dn));
+	}
+
 	/**
 	 * Update a DN entry
 	 *
@@ -322,7 +405,7 @@ class HomeController extends Controller
 			$o->{$key} = array_filter($value);
 
 		if (! $dirty=$o->getDirty())
-			return back()
+			return Redirect::back()
 				->withInput()
 				->with('note',__('No attributes changed'));
 
@@ -348,7 +431,7 @@ class HomeController extends Controller
 				->with('failed',sprintf('%s: %s - %s: %s',
 					__('LDAP Server Error Code'),
 					$e->getDetailedError()->getErrorCode(),
-					__($e->getDetailedError()->getErrorMessage()),
+					$e->getDetailedError()->getErrorMessage(),
 					$e->getDetailedError()->getDiagnosticMessage(),
 				));
 		}
@@ -356,7 +439,9 @@ class HomeController extends Controller
 		return Redirect::to('/')
 			->withInput()
 			->with('updated',collect($dirty)
-				->map(fn($item,$key)=>$o->getObject(collect(explode(';',$key))->first())));
+				->map(fn($item,$key)=>$o->getObject(collect(explode(';',$key))->first()))
+				->values()
+				->unique());
 	}
 
 	/**
@@ -366,6 +451,7 @@ class HomeController extends Controller
 	 * @param Request $request
 	 * @param Collection|null $old
 	 * @return \Illuminate\View\View
+	 * @throws InvalidUsage
 	 */
 	public function frame(Request $request,?Collection $old=NULL): \Illuminate\View\View
 	{
@@ -375,31 +461,37 @@ class HomeController extends Controller
 
 		$key = $this->request_key($request,$old);
 
-		$view = ($old
+		$view = $old
 			? view('frame')->with('subframe',$key['cmd'])
-			: view('frames.'.$key['cmd']))
-			->with('bases',$this->bases());
+			: view('frames.'.$key['cmd']);
 
 		// If we are rendering a DN, rebuild our object
-		if ($key['dn']) {
+		if ($key['cmd'] === 'create') {
+			$o = new Entry;
+			$o->setRDNBase($key['dn']);
+
+		} elseif ($key['dn']) {
+			// @todo Need to handle if DN is null, for example if the user's session expired and the ACLs dont let them retrieve $key['dn']
 			$o = config('server')->fetch($key['dn']);
 
-			foreach (collect(old())->except(['key','dn','step','_token','userpassword_hash','rdn','rdn_value']) as $attr => $value)
+			foreach (collect(old())->except(array_merge(self::INTERNAL_POST,['dn'])) as $attr => $value)
 				$o->{$attr} = $value;
 		}
 
 		return match ($key['cmd']) {
 			'create' => $view
 				->with('container',old('container',$key['dn']))
+				->with('o',$o)
+				->with('template',NULL)
 				->with('step',1),
 
 			'dn' => $view
 				->with('dn',$key['dn'])
 				->with('o',$o)
 				->with('page_actions',collect([
-					'copy'=>FALSE,
 					'create'=>($x=($o->getObjects()->except('entryuuid')->count() > 0)),
-					'delete'=>$x,
+					'copy'=>$x,
+					'delete'=>(! is_null($xx=$o->getObject('hassubordinates')->value)) && ($xx === 'FALSE'),
 					'edit'=>$x,
 					'export'=>$x,
 				])),
@@ -418,8 +510,7 @@ class HomeController extends Controller
 		// Did we come here as a result of a redirect
 		return count(old())
 			? $this->frame($request,collect(old()))
-			: view('home')
-				->with('bases',$this->bases());
+			: view('home');
 	}
 
 	/**
@@ -447,19 +538,44 @@ class HomeController extends Controller
 			$result = $import->process();
 
 		} catch (NotImplementedException $e) {
+			Log::error(sprintf('Import Exception [%s]',$e->getMessage()));
+
 			abort(555,$e->getMessage());
 
 		} catch (\Exception $e) {
+			Log::error(sprintf('Import Exception [%s]',$e->getMessage()));
+
 			abort(598,$e->getMessage());
 		}
 
 		return view('frame')
 			->with('subframe','import_result')
-			->with('bases',$this->bases())
 			->with('result',$result)
 			->with('ldif',htmlspecialchars($x));
 	}
 
+	private function password(Password $po,array $values,array $hash): array
+	{
+		// We need to process and encrypt the password
+		$passwords = [];
+
+		foreach (Arr::dot($values) as $dotkey => $value) {
+			// If the password is still the MD5 of the old password, then it hasnt changed
+			if (($old=Arr::get($po,$dotkey)) && ($value === md5($old))) {
+				$passwords[$dotkey] = $value;
+				continue;
+			}
+
+			if ($value) {
+				$type = Arr::get($hash,$dotkey);
+				$passwords[$dotkey] = Password::hash_id($type)
+					->encode($value);
+			}
+		}
+
+		return Arr::undot($passwords);
+	}
+
 	/**
 	 * For any incoming request, work out the command and DN involved
 	 *
@@ -472,8 +588,8 @@ class HomeController extends Controller
 		// Setup
 		$cmd = NULL;
 		$dn = NULL;
-		$key = $request->get('key',old('key'))
-			? Crypt::decryptString($request->get('key',old('key')))
+		$key = ($x=$request->get('_key',old('_key')))
+			? Crypt::decryptString($x)
 			: NULL;
 
 		// Determine if our key has a command
@@ -485,9 +601,9 @@ class HomeController extends Controller
 				$dn = ($m[2] !== '_NOP') ? $m[2] : NULL;
 			}
 
-		} elseif (old('dn',$request->get('key'))) {
+		} elseif ($x=old('dn',$request->get('_key'))) {
 			$cmd = 'dn';
-			$dn = Crypt::decryptString(old('dn',$request->get('key')));
+			$dn = Crypt::decryptString($x);
 		}
 
 		return ['cmd'=>$cmd,'dn'=>$dn];
@@ -504,12 +620,12 @@ class HomeController extends Controller
 	public function schema_frame(Request $request): \Illuminate\View\View
 	{
 		// If an invalid key, we'll 404
-		if ($request->type && $request->key && (! config('server')->schema($request->type)->has($request->key)))
+		if ($request->type && $request->get('_key') && (! config('server')->schema($request->type)->has($request->get('_key'))))
 			abort(404);
 
 		return view('frames.schema')
 			->with('type',$request->type)
-			->with('key',$request->key);
+			->with('key',$request->get('_key'));
 	}
 
 	/**
