@@ -3,11 +3,16 @@
 namespace App\Ldap;
 
 use Illuminate\Support\Collection;
+use Illuminate\Support\Facades\Cache;
 use Illuminate\Support\Facades\Crypt;
+use Illuminate\Support\Facades\Log;
+use Illuminate\Support\Facades\Session;
+use Illuminate\Support\Facades\Storage;
+use Illuminate\Support\Str;
 use LdapRecord\Support\Arr;
 use LdapRecord\Models\Model;
-use LdapRecord\Query\Model\Builder;
 
+use App\Classes\Template;
 use App\Classes\LDAP\Attribute;
 use App\Classes\LDAP\Attribute\Factory;
 use App\Classes\LDAP\Export\LDIF;
@@ -22,23 +27,49 @@ use App\Exceptions\InvalidUsage;
 class Entry extends Model
 {
 	private const TAG_CHARS = 'a-zA-Z0-9-';
-	private const TAG_CHARS_LANG = 'lang-['.self::TAG_CHARS.']';
+	public const LANG_TAG_PREFIX = 'lang-';
+	public const TAG_CHARS_LANG = self::LANG_TAG_PREFIX.'['.self::TAG_CHARS.']+';
 	public const TAG_NOTAG = '_null_';
 
 	// Our Attribute objects
 	private Collection $objects;
-	/* @deprecated */
-	private bool $noObjectAttributes = FALSE;
+
+	// Templates that apply to this entry
+	private(set) Collection $templates;
+
 	// For new entries, this is the container that this entry will be stored in
 	private string $rdnbase;
+	private(set) bool $is_base;
 
 	/* OVERRIDES */
 
 	public function __construct(array $attributes = [])
 	{
+		parent::__construct($attributes);
+
 		$this->objects = collect();
 
-		parent::__construct($attributes);
+		// Load any templates
+		$this->templates = Cache::remember('templates'.Session::id(),config('ldap.cache.time'),function() {
+			$template_dir = Storage::disk(config('pla.template.dir'));
+			$templates = collect();
+
+			foreach (array_filter($template_dir->files('.',TRUE),fn($item)=>Str::endsWith($item,'.json')) as $file) {
+				if (config('pla.template.exclude_system',FALSE) && Str::doesntContain($file,'/'))
+					continue;
+
+				$to = new Template($file);
+
+				if ($to->invalid) {
+					Log::alert(sprintf('Template [%s] is not valid (%s) - ignoring',$file,$to->reason));
+
+				} else {
+					$templates->put($file,new Template($file));
+				}
+			}
+
+			return $templates;
+		});
 	}
 
 	public function discardChanges(): static
@@ -61,18 +92,41 @@ class Entry extends Model
 	public function getAttributes(): array
 	{
 		return $this->objects
+			->filter(fn($item)=>(! $item->is_internal))
 			->flatMap(fn($item)=>
-				($item->no_attr_tags)
+				$item->no_attr_tags
 					? [strtolower($item->name)=>$item->values]
 					: $item->values
-						->flatMap(fn($v,$k)=>[strtolower($item->name.($k !== self::TAG_NOTAG ? ';'.$k : ''))=>$v]))
+						->flatMap(fn($v,$k)=>[strtolower($item->name.(($k !== self::TAG_NOTAG) ? ';'.$k : ''))=>$v]))
 			->toArray();
 	}
 
 	/**
-	 * Determine if the new and old values for a given key are equivalent.
+	 * This replaces the model's get dirty, given that we store LDAP attributes in $this->objects, replacing
+	 * $this->original/$this->attributes
 	 *
-	 * @todo This function barfs on language tags, eg: key = givenname;lang-ja
+	 * @return array
+	 */
+	public function getDirty(): array
+	{
+		$result = collect();
+
+		foreach ($this->objects as $o)
+			if ($o->isDirty())
+				$result = $result->merge($o->getDirty());
+
+		$result = $result
+			->flatMap(function($item,$attr) {
+				return ($x=collect($item))->count()
+					? $x->flatMap(fn($v,$k)=>[strtolower($attr.(($k !== self::TAG_NOTAG) ? ';'.$k : ''))=>$v])
+					: [strtolower($attr)=>[]];
+			});
+
+		return $result->toArray();
+	}
+
+	/**
+	 * Determine if the new and old values for a given key are equivalent.
 	 */
 	protected function originalIsEquivalent(string $key): bool
 	{
@@ -84,16 +138,6 @@ class Entry extends Model
 			|| (! $this->getObject($attribute)->isDirty());
 	}
 
-	public static function query(bool $noattrs=false): Builder
-	{
-		$o = new static;
-
-		if ($noattrs)
-			$o->noObjectAttributes();
-
-		return $o->newQuery();
-	}
-
 	/**
 	 * As attribute values are updated, or new ones created, we need to mirror that
 	 * into our $objects. This is called when we $o->key = $value
@@ -140,6 +184,17 @@ class Entry extends Model
 			$this->objects = collect();
 		}
 
+		// Filter out our templates specific for this entry
+		if ($this->dn && (! in_array(strtolower($this->dn),['cn=subschema']))) {
+			$this->templates = $this->templates
+				->filter(fn($item)=>$item->enabled
+					&& (! $item->objectclasses
+						->map('strtolower')
+						->diff(array_map('strtolower',Arr::get($this->attributes,'objectclass')))
+						->count()))
+				->sortBy(fn($item)=>$item->title);
+		}
+
 		return $this;
 	}
 
@@ -179,13 +234,13 @@ class Entry extends Model
 		// If the attribute name has tags
 		list($attribute,$tag) = $this->keytag($key);
 
-		if (! config('server')->schema('attributetypes')->has($attribute))
+		if (config('server')->get_attr_id($attribute) === FALSE)
 			throw new AttributeException(sprintf('Schema doesnt have attribute [%s]',$attribute));
 
 		$o = $this->objects->get($attribute) ?: Attribute\Factory::create($this->dn ?: '',$attribute,[]);
 		$o->addValue($tag,[$value]);
 
-		$this->objects->put($attribute,$o);
+		$this->objects->put($key,$o);
 	}
 
 	/**
@@ -288,8 +343,8 @@ class Entry extends Model
 	{
 		$result = collect();
 
-		foreach ($this->getObject('objectclass')->values as $oc)
-			$result = $result->merge(config('server')->schema('objectclasses',$oc)->attributes);
+		foreach (($this->getObject('objectclass')?->values ?: []) as $oc)
+			$result = $result->merge(config('server')->schema('objectclasses',$oc)->all_attributes);
 
 		return $result;
 	}
@@ -323,14 +378,7 @@ class Entry extends Model
 	public function getLangTags(): Collection
 	{
 		return $this->getObjects()
-			->filter(fn($item)=>! $item->no_attr_tags)
-			->map(fn($item)=>$item
-				->values
-				->keys()
-				->filter(fn($item)=>preg_match(sprintf('/%s+;?/',self::TAG_CHARS_LANG),$item))
-				->map(fn($item)=>preg_replace('/lang-/','',$item))
-			)
-			->filter(fn($item)=>$item->count());
+			->map(fn($item)=>$item->langtags);
 	}
 
 	/**
@@ -388,7 +436,7 @@ class Entry extends Model
 					$item && collect(explode(';',$item))->filter(
 						fn($item)=>
 							(! preg_match(sprintf('/^%s$/',self::TAG_NOTAG),$item))
-							&& (! preg_match(sprintf('/^%s+$/',self::TAG_CHARS_LANG),$item))
+							&& (! preg_match(sprintf('/^%s$/',self::TAG_CHARS_LANG),$item))
 						)
 						->count())
 			)
@@ -399,9 +447,6 @@ class Entry extends Model
 	 * Return a list of attributes without any values
 	 *
 	 * @return Collection
-	 * @todo Dont show attributes that are not provided by an objectclass, make a new function to show those
-	 *       This is for dynamic list items eg: labeledURI, which are not editable.
-	 *       We can highlight those values that are as a result of a dynamic module
 	 */
 	public function getMissingAttributes(): Collection
 	{
@@ -414,7 +459,7 @@ class Entry extends Model
 		$o = new Attribute\RDN('','dn',['']);
 		// @todo for an existing object, rdnbase would be null, so dynamically get it from the DN.
 		$o->setBase($this->rdnbase);
-		$o->setAttributes($this->getAvailableAttributes()->filter(fn($item)=>$item->required));
+		$o->setAttributes($this->getAvailableAttributes()->filter(fn($item)=>$item->is_must));
 
 		return $o;
 	}
@@ -433,7 +478,7 @@ class Entry extends Model
 			$ot = $this->getOtherTags();
 
 			$cache[$tag ?: '_all_'] = $this->objects
-				->filter(fn($item)=>(! $item->is_internal) && ((! $item->no_attr_tags) || (! $tag) || ($tag === Entry::TAG_NOTAG)))
+				->filter(fn($item)=>(! $item->is_internal) && ((! $item->no_attr_tags) || (! $tag) || ($tag === self::TAG_NOTAG)))
 				->filter(fn($item)=>(! $tag) || $ot->has($item->name_lc) || count($item->tagValues($tag)) > 0);
 		}
 
@@ -446,6 +491,21 @@ class Entry extends Model
 			->has($key);
 	}
 
+	/**
+	 * Did this query generate a size limit exception
+	 *
+	 * @return bool
+	 * @throws \LdapRecord\ContainerException
+	 */
+	public function hasMore(): bool
+	{
+		return $this->getConnectionContainer()
+			->getConnection()
+			->getLdapConnection()
+			->getDetailedError()
+			?->getErrorCode() === 4;
+	}
+
 	/**
 	 * Return an icon for a DN based on objectClass
 	 *
@@ -453,9 +513,10 @@ class Entry extends Model
 	 */
 	public function icon(): string
 	{
-		$objectclasses = $this->getObject('objectclass')
-			->tagValues()
-			->map(fn($item)=>strtolower($item));
+		$objectclasses = ($x=$this->getObject('objectclass'))
+			? $x->tagValues()
+				->map(fn($item)=>strtolower($item))
+			: collect();
 
 		// Return icon based upon objectClass value
 		if ($objectclasses->intersect([
@@ -540,16 +601,13 @@ class Entry extends Model
 	}
 
 	/**
-	 * Dont convert our $this->attributes to $this->objects when creating a new Entry::class
+	 * Is this entry a baseDN
 	 *
-	 * @return $this
-	 * @deprecated
+	 * @return void
 	 */
-	public function noObjectAttributes(): static
+	public function setBase(): void
 	{
-		$this->noObjectAttributes = TRUE;
-
-		return $this;
+		$this->is_base = TRUE;
 	}
 
 	public function setRDNBase(string $bdn): void
@@ -558,5 +616,13 @@ class Entry extends Model
 			throw new InvalidUsage('Cannot set RDN base on existing entries');
 
 		$this->rdnbase = $bdn;
+
+		$this->templates = $this->templates
+			->filter(fn($item)=>(! $item->regexp) || preg_match($item->regexp,$bdn));
+	}
+
+	public function template(string $item): Template|Null
+	{
+		return Arr::get($this->templates,$item);
 	}
 }
\ No newline at end of file
