@@ -1,32 +1,27 @@
 <?php
 
-use Illuminate\Cookie\Middleware\EncryptCookies;
 use Illuminate\Foundation\Application;
 use Illuminate\Foundation\Configuration\Exceptions;
 use Illuminate\Foundation\Configuration\Middleware;
 
-use App\Http\Middleware\{AllowAnonymous,ApplicationSession,CheckUpdate,SwapinAuthUser};
+use App\Http\Middleware\{AcceptLanguage,AllowAnonymous,CheckUpdate,SwapinAuthUser,ViewVariables};
 
 return Application::configure(basePath: dirname(__DIR__))
 	->withRouting(
 		web: __DIR__.'/../routes/web.php',
-		api: __DIR__.'/../routes/api.php',
 		commands: __DIR__.'/../routes/console.php',
 		health: '/up',
 	)
 	->withMiddleware(function (Middleware $middleware) {
-		$middleware->appendToGroup('web', [
-			SwapinAuthUser::class,
-			ApplicationSession::class,
-			CheckUpdate::class,
-		]);
-
-		$middleware->prependToGroup('api', [
-			EncryptCookies::class,
-			SwapinAuthUser::class,
-			ApplicationSession::class,
-			AllowAnonymous::class,
-		]);
+		$middleware->appendToGroup(
+			group: 'web',
+			middleware: [
+				AcceptLanguage::class,
+				AllowAnonymous::class,
+				SwapinAuthUser::class,
+				ViewVariables::class,
+				CheckUpdate::class,
+			]);
 
 		$middleware->trustProxies(at: [
 			'10.0.0.0/8',
