@@ -35,7 +35,6 @@ return [
 			'username' => env('LDAP_USERNAME', 'cn=user,dc=local,dc=com'),
 			'password' => env('LDAP_PASSWORD', 'secret'),
 			'port' => env('LDAP_PORT', 389),
-			'base_dn' => env('LDAP_BASE_DN', 'dc=local,dc=com'),
 			'timeout' => env('LDAP_TIMEOUT', 5),
 			'use_ssl' => env('LDAP_SSL', false),
 			'use_tls' => env('LDAP_TLS', false),
@@ -47,7 +46,6 @@ return [
 			'username' => env('LDAP_USERNAME', 'cn=user,dc=local,dc=com'),
 			'password' => env('LDAP_PASSWORD', 'secret'),
 			'port' => env('LDAP_PORT', 636),
-			'base_dn' => env('LDAP_BASE_DN', 'dc=local,dc=com'),
 			'timeout' => env('LDAP_TIMEOUT', 5),
 			'use_ssl' => env('LDAP_SSL', true),
 			'use_tls' => env('LDAP_TLS', false),
@@ -59,7 +57,6 @@ return [
 			'username' => env('LDAP_USERNAME', 'cn=user,dc=local,dc=com'),
 			'password' => env('LDAP_PASSWORD', 'secret'),
 			'port' => env('LDAP_PORT', 389),
-			'base_dn' => env('LDAP_BASE_DN', 'dc=local,dc=com'),
 			'timeout' => env('LDAP_TIMEOUT', 5),
 			'use_ssl' => env('LDAP_SSL', false),
 			'use_tls' => env('LDAP_TLS', true),
@@ -72,7 +69,6 @@ return [
 			'username' => 'cn=Directory Manager',
 			'password' => 'password',
 			'port' => 1389,
-			'base_dn' => 'dc=example,dc=com',
 			'timeout' => env('LDAP_TIMEOUT', 5),
 			'use_ssl' => env('LDAP_SSL', false),
 			'use_tls' => env('LDAP_TLS', false),
@@ -122,47 +118,47 @@ return [
 	 */
 	'validation' => [
 		'objectclass' => [
-			'objectclass'=>[
+			'objectclass.*'=>[
 				new HasStructuralObjectClass,
 			]
 		],
 		'gidnumber' => [
-			'gidnumber'=> [
+			'gidnumber.*'=> [
 				'sometimes',
 				'max:1'
 			],
-			'gidnumber.*' => [
+			'gidnumber.*.*' => [
 				'nullable',
 				'integer',
 				'max:65535'
 			]
 		],
 		'mail' => [
-			'mail'=>[
+			'mail.*'=>[
 				'sometimes',
 				'min:1'
 			],
-			'mail.*' => [
+			'mail.*.*' => [
 				'nullable',
 				'email'
 			]
 		],
 		'userpassword' => [
-			'userpassword' => [
+			'userpassword.*' => [
 				'sometimes',
 				'min:1'
 			],
-			'userpassword.*' => [
+			'userpassword.*.*' => [
 				'nullable',
 				'min:8'
 			]
 		],
 		'uidnumber' => [
-			'uidnumber' => [
+			'uidnumber.*' => [
 				'sometimes',
 				'max:1'
 			],
-			'uidnumber.*' => [
+			'uidnumber.*.*' => [
 				'nullable',
 				'integer',
 				'max:65535'
