@@ -15,7 +15,7 @@ function getNode(item) {
 	$.ajax({
 		url: '/frame',
 		method: 'POST',
-		data: { key: item },
+		data: { _key: item },
 		dataType: 'html',
 		beforeSend: function() {
 			content = $('.main-content')
@@ -37,11 +37,11 @@ function getNode(item) {
 				$('.main-content').empty().append(e.responseText);
 				break;
 			case 409:	// Not in root
-				location.replace('/#'+item);
-				break;
 			case 419:	// Session Expired
 				location.replace('/#'+item);
-				location.reload();
+				// When the session expires, and we are in the tree, we need to force a reload
+				if (location.pathname === '/')
+					location.reload();
 				break;
 			case 500:
 			case 555:	// Missing Method
@@ -59,7 +59,7 @@ $(document).ready(function() {
 	if (typeof basedn !== 'undefined') {
 		sources = basedn;
 	} else {
-		sources = { url: 'api/bases' };
+		sources = { method: 'POST', url: '/ajax/bases' };
 	}
 
 	// Attach the fancytree widget to an existing <div id="tree"> element
@@ -89,14 +89,15 @@ $(document).ready(function() {
 			types: 'active expanded focus selected'  // which status types to store
 		},
 		click: function(event,data) {
-			if (data.targetType === 'title')
+			if (data.targetType === 'title' && data.node.data.item)
 				getNode(data.node.data.item);
 		},
 		source: sources,
 		lazyLoad: function(event,data) {
 			data.result = {
-				url: '/api/children',
-				data: {key: data.node.data.item,depth: 1}
+				method: 'POST',
+				url: '/ajax/children',
+				data: {_key: data.node.data.item,create: true}
 			};
 
 			expandChildren(data.tree.rootNode);
