@@ -38,7 +38,7 @@
 						<span></span>
 						<div id="searching" class="d-none"><i class="fas fa-fw fa-spinner fa-pulse text-light"></i></div>
 					</button>
-					<div id="search_results" style="height: 300px; overflow: scroll"></div>
+					<div id="search_results"></div>
 				</div>
 				<button class="btn-close"></button>
 			</div>
@@ -139,10 +139,10 @@
 							<div class="btn-group">
 								<a data-bs-toggle="dropdown" aria-haspopup="true" aria-expanded="false" class="p-0 btn">
 									<i class="fas fa-angle-down ms-2 opacity-8"></i>
-									<img width="35" height="35" class="rounded-circle" src="{{ url('user/image') }}" alt="" style="background-color: #eee;padding: 2px;">
+									<img width="35" height="35" class="rounded-circle p-1 bg-light" src="{{ url('user/image') }}" alt="">
 								</a>
 								<div tabindex="-1" role="menu" aria-hidden="true" class="dropdown-menu dropdown-menu-right">
-									@if ($user->exists)
+									@if($user->exists)
 										<h6 tabindex="-1" class="dropdown-header text-center">User Menu</h6>
 										<div tabindex="-1" class="dropdown-divider"></div>
 										<a href="{{ url('logout') }}" tabindex="0" class="dropdown-item">
@@ -164,18 +164,14 @@
 </div>
 
 @section('page-scripts')
-	<style>
-		#search_results ul.typeahead.dropdown-menu {
-			overflow: scroll;
-			max-height: 300px;
-		}
-	</style>
-
 	<script type="text/javascript">
 		$(document).ready(function() {
 			$('button[id^="link-"]').on('click',function(item) {
 				var content;
 
+				// Remove our fancy-tree highlight, since we are rendering the frame
+				$('.fancytree-node.fancytree-active').removeClass('fancytree-active');
+
 				$.ajax({
 					url: $(this).data('link'),
 					method: 'GET',
