@@ -1,6 +1,8 @@
+@use(App\Ldap\Entry)
+
 <!-- @todo We are not handling redirect backs yet with updated photos -->
 <!-- $o=Binary\JpegPhoto::class -->
-<x-attribute.layout :edit="$edit" :new="$new" :o="$o" :langtag="$langtag">
+<x-attribute.layout :edit="$edit" :new="$new" :o="$o">
 	<table class="table table-borderless p-0 m-0">
 		@foreach($o->tagValuesOld() as $key => $value)
 			<tr>
@@ -8,8 +10,8 @@
 					@case('image/jpeg')
 					@default
 						<td>
-							<input type="hidden" name="{{ $o->name_lc }}[{{ $langtag }}][]" value="{{ md5($value) }}">
-							<img alt="{{ $o->dn }}" @class(['border','rounded','p-2','m-0','is-invalid'=>($e=$errors->get($o->name_lc.'.'.$langtag.'.'.$loop->index))]) src="data:{{ $x }};base64, {{ base64_encode($value) }}" />
+							<input type="hidden" name="{{ $o->name_lc }}[{{ Entry::TAG_NOTAG }}][]" value="{{ md5($value) }}">
+							<img alt="{{ $o->dn }}" @class(['border','rounded','p-2','m-0','is-invalid'=>($e=$errors->get($o->name_lc.'.'.Entry::TAG_NOTAG.'.'.$loop->index)),'bg-success-subtle'=>$updated]) src="data:{{ $x }};base64, {{ base64_encode($value) }}" />
 
 							@if($edit)
 								<br>
