@@ -1,4 +1,4 @@
-<!-- $o=Internal::class -->
+<!-- $o=Attribute|Internal::class -->
 @foreach(old($o->name_lc,$o->values) as $value)
 	@if($loop->index)<br>@endif
 	{{ $value }}
