@@ -3,10 +3,7 @@
 @extends('layouts.dn')
 
 @section('page_title')
-	@include('fragment.dn.header',[
-		'o'=>($oo=$server->fetch(old('container',$container))),
-		'langtags'=>collect(),
-	])
+	@include('fragment.dn.header',['o'=>($oo=$server->fetch(old('container',$container)))])
 @endsection
 
 @section('page_status')
@@ -20,52 +17,72 @@
 			<div class="main-card mb-3 card">
 
 				<div class="card-header">
-					@lang('Create New Entry') - @lang('Step') {{ $step }}
+					@lang('Create New Entry') - @lang('Step') {{ $step }} @if($template) <span class="ms-auto"><i class="fa fa-fw {{ $template->icon }}"></i> {{ $template->title }}</span>@endif
 				</div>
 
 				<div class="card-body">
 					<form id="dn-create" method="POST" class="needs-validation" action="{{ url((int)$step === 2 ? 'entry/create' : 'entry/add') }}" enctype="multipart/form-data" novalidate>
 						@csrf
 
-						<input type="hidden" name="key" value="{{ Crypt::encryptString('*create|'.$container) }}">
-						<input type="hidden" name="step" value="{{ $step }}">
+						<input type="hidden" name="_key" value="{{ Crypt::encryptString('*create|'.$container) }}">
+						<input type="hidden" name="_step" value="{{ $step }}">
 
 						@switch($step)
 							@case(1)
 								<div class="row">
-									<div class="col-12 col-md-6">
+									<div class="col-12 col-md-5">
 										<x-form.select
 											id="objectclass"
 											name="objectclass[{{ Entry::TAG_NOTAG }}][]"
 											old="objectclass.{{ Entry::TAG_NOTAG }}"
-											:label="__('Select a Structural ObjectClass...')"
+											:label="__('Select a Structural ObjectClass').'...'"
 											:options="($oc=$server->schema('objectclasses'))
 												->filter(fn($item)=>$item->isStructural())
 												->sortBy(fn($item)=>$item->name_lc)
 												->map(fn($item)=>['id'=>$item->name,'value'=>$item->name])"
-											multiple="false"
+											:allowclear="true"
 										/>
 									</div>
+
+									@if($o->templates->count())
+										<div class="col-md-1">
+											<strong>@lang('OR')</strong>
+										</div>
+
+										<div class="col-12 col-md-5">
+											<x-form.select
+												name="template"
+												:label="__('Select a Template').'...'"
+												:options="$o->templates
+													->map(fn($item,$key)=>['id'=>$key,'value'=>$item->title])"
+												:allowclear="true"
+											/>
+										</div>
+									@endif
 								</div>
 								@break
 
 							@case(2)
-								<x-attribute-type :o="$o->getObject('rdn')" :edit="TRUE" :new="FALSE" :langtag="Entry::TAG_NOTAG" :updated="FALSE"/>
+								<input type="hidden" name="_template" value="{{ $template?->file }}">
+								<x-attribute-type :o="$o->getObject('rdn')" :edit="true" :new="true" :template="$template" :updated="false"/>
 
-								@foreach ($o->getVisibleAttributes() as $ao)
-									<x-attribute-type :o="$ao" :edit="TRUE" :new="FALSE" :langtag="Entry::TAG_NOTAG" :updated="FALSE"/>
+								@foreach($o->getVisibleAttributes() as $ao)
+									<x-attribute-type :o="$ao" :edit="true" :new="true" :template="$template" :updated="false"/>
 								@endforeach
 
-								@include('fragment.dn.add_attr')
-
+								@if(! $template)
+									<!-- @todo When we come back from validation the javascript to append a new attribute is not loaded -->
+									<!-- @todo When we render attributes with javascript, the javascript is not loaded -->
+									@include('fragment.dn.add_attr')
+								@endif
 								@break;
 						@endswitch
 					</form>
 
 					<div class="row d-none pt-3">
-						<div class="col-12 {{ $step > 1 ? 'offset-sm-2' : '' }} col-lg-10">
+						<div class="col-11 {{ $step > 1 ? 'text-end' : '' }} pe-0">
 							<x-form.reset form="dn-create"/>
-							<x-form.submit action="Next" form="dn-create"/>
+							<x-form.submit :action="__('Next')" form="dn-create"/>
 						</div>
 					</div>
 				</div>
@@ -75,14 +92,13 @@
 @endsection
 
 @section('page-scripts')
-
 	<script type="text/javascript">
 		var rdn_attr;
 
 		function editmode() {
 			// Find all input items and turn off readonly
 			$('input.form-control').each(function() {
-				// Except for objectClass - @todo show an "X" instead
+				// Except for objectClass
 				if ($(this)[0].name.match(/^objectclass/))
 					return;
 
@@ -90,11 +106,15 @@
 				if (rdn_attr && ($(this)[0].name === rdn_attr+'[]'))
 					return;
 
+				// Exclude attributes marked as noedit
+				if ($(this).hasClass('noedit'))
+					return;
+
 				$(this).attr('readonly',false);
 			});
 
 			// Our password type
-			$('attribute#userPassword .form-select').each(function() {
+			$('attribute#userpassword .form-select').each(function() {
 				$(this).prop('disabled',false);
 			})
 
@@ -105,9 +125,17 @@
 		}
 
 		$(document).ready(function() {
-			@if($step === 2)
+			@if($step === 1)
+				$('#objectclass').on('select2:open',function(){
+					$('#template').val(null).trigger('change');
+				});
+
+				$('#template').on('select2:open',function(){
+					$('#objectclass').val(null).trigger('change');
+				})
+			@elseif($step === 2)
 				$('#newattr').on('change',function(item) {
-					var oc = $('attribute#objectClass input[type=text]')
+					var oc = $('attribute#objectclass input[type=text]')
 						.map((key,item)=>{return $(item).val()}).toArray();
 
 					$.ajax({
