@@ -9,25 +9,31 @@
 		<div class="col">
 			<div class="action-buttons float-end">
 				<ul class="nav">
-					@if(isset($page_actions) && $page_actions->contains('export'))
+					@if($page_actions->get('create'))
+						<li>
+							<button class="btn btn-outline-dark p-1 m-1" id="entry-create" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Create Child Entry')"><i class="fas fa-fw fa-diagram-project fs-5"></i></button>
+						</li>
+					@endif
+					@if($page_actions->get('export'))
 						<li>
 							<span id="entry-export" data-bs-toggle="modal" data-bs-target="#page-modal">
 								<button class="btn btn-outline-dark p-1 m-1" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Export')"><i class="fas fa-fw fa-download fs-5"></i></button>
 							</span>
 						</li>
 					@endif
-					@if(isset($page_actions) && $page_actions->contains('copy'))
+					@if($page_actions->get('copy'))
 						<li>
-							<button class="btn btn-outline-dark p-1 m-1" id="entry-copy-move" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Copy/Move')" disabled><i class="fas fa-fw fa-copy fs-5"></i></button>
+							<span id="entry-copy-move" data-bs-toggle="modal" data-bs-target="#page-modal">
+								<button class="btn btn-outline-dark p-1 m-1" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Copy/Move')"><i class="fas fa-fw fa-copy fs-5"></i></button>
+							</span>
 						</li>
 					@endif
-					@if((isset($page_actions) && $page_actions->contains('edit')) || old())
+					@if($page_actions->get('edit'))
 						<li>
 							<button class="btn btn-outline-dark p-1 m-1" id="entry-edit" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Edit Entry')"><i class="fas fa-fw fa-edit fs-5"></i></button>
 						</li>
 					@endif
-					<!-- @todo Dont offer the delete button for an entry with children -->
-					@if(isset($page_actions) && $page_actions->contains('delete'))
+					@if($page_actions->get('delete'))
 						<li>
 							<span id="entry-delete" data-bs-toggle="modal" data-bs-target="#page-modal">
 								<button class="btn btn-outline-danger p-1 m-1" data-bs-custom-class="custom-tooltip-danger" data-bs-toggle="tooltip" data-bs-placement="bottom" title="@lang('Delete Entry')"><i class="fas fa-fw fa-trash-can fs-5"></i></button>
@@ -40,66 +46,89 @@
 	</div>
 @endsection
 
-@section('main-content')
-	<x-note/>
-	<x-updated/>
-	<x-error/>
+@section('page_status')
+	@if(($x=$o->getOtherTags()->filter(fn($item)=>$item->diff(['binary'])->count()))->count())
+		<div class="alert alert-danger p-2">
+			This entry has [<strong>{!! $x->flatten()->join('</strong>, <strong>') !!}</strong>] tags used by [<strong>{!! $x->keys()->join('</strong>, <strong>') !!}</strong>] that cant be managed by PLA. You can though manage those tags with an LDIF import.
+		</div>
+	@endif
 
+	<x-success/>
+	<x-updated/>
+	<x-note/>
+	<x-error/>
+	<x-failed/>
+@endsection
+
+@section('main-content')
 	<div class="main-card mb-3 card">
 		<div class="card-body">
 			<div class="card-header-tabs">
-				<ul class="nav nav-tabs">
+				<ul class="nav nav-tabs mb-0">
 					<li class="nav-item"><a data-bs-toggle="tab" href="#attributes" class="nav-link active">@lang('Attributes')</a></li>
 					<li class="nav-item"><a data-bs-toggle="tab" href="#internal" class="nav-link">@lang('Internal')</a></li>
-					@env(['local'])
-						<li class="nav-item"><a data-bs-toggle="tab" href="#debug" class="nav-link">@lang('Debug')</a></li>
-					@endenv
 				</ul>
 
 				<div class="tab-content">
 					<!-- All Attributes -->
 					<div class="tab-pane active" id="attributes" role="tabpanel">
-						<form id="dn-edit" method="POST" class="needs-validation" action="{{ url('entry/update/pending') }}" novalidate readonly>
-							@csrf
+						<div class="row pt-3">
+							<div class="col-12">
+								<div class="d-flex justify-content-center">
+									<div role="group" class="btn-group btn-group-sm nav pb-3">
+										<!-- If we have templates that cover this entry -->
+										@foreach($o->templates as $template)
+											<span data-bs-toggle="tab" href="#template-{{ $template->name }}" @class(['btn','btn-outline-focus','active'=>$loop->index === 0])><i class="fa fa-fw pe-2 {{ $template->icon }}"></i> {{ $template->title }}</span>
+										@endforeach
+										@if($o->templates->count())
+											<span data-bs-toggle="tab" href="#template-default" @class(['btn','btn-outline-focus','p-1','active'=>(! $o->templates->count())])><i class="fa fa-fw fa-list pe-2"></i> {{ __('LDAP Entry') }}</span>
+										@endif
+									</div>
+								</div>
 
-							<input type="hidden" name="dn" value="">
+								<div class="tab-content">
+									@foreach($o->templates as $template)
+										<div @class(['tab-pane','active'=>$loop->index === 0]) id="template-{{ $template->name }}" role="tabpanel">
+											@include('fragment.template.dn',['template'=>$template])
+										</div>
+									@endforeach
 
-							@foreach ($o->getVisibleAttributes() as $ao)
-								<x-attribute-type :edit="true" :o="$ao"/>
-							@endforeach
+									<div @class(['tab-pane','active'=>(! $o->templates->count())]) id="template-default" role="tabpanel">
+										<form id="dn-edit" method="POST" class="needs-validation" action="{{ url('entry/update/pending') }}" novalidate readonly>
+											@csrf
 
-							@include('fragment.dn.add_attr')
-						</form>
+											<input type="hidden" name="dn" value="">
 
-						<div class="row d-none pt-3">
-							<div class="col-12 offset-sm-2 col-sm-4 col-lg-2">
-								<x-form.reset form="dn-edit"/>
-								<x-form.submit action="Update" form="dn-edit"/>
+											<div class="card-body">
+												<div class="tab-content">
+													@php($up=(session()->pull('updated') ?: collect()))
+													@foreach($o->getVisibleAttributes() as $ao)
+														<x-attribute-type :o="$ao" :edit="true" :new="false" :template="null" :updated="$up->contains($ao->name)"/>
+													@endforeach
+
+													@include('fragment.dn.add_attr')
+												</div>
+											</div>
+										</form>
+
+										<div class="row d-none pt-3">
+											<div class="col-11 text-end">
+												<x-form.reset form="dn-edit"/>
+												<x-form.submit :action="__('Update')" form="dn-edit"/>
+											</div>
+										</div>
+									</div>
+								</div>
 							</div>
 						</div>
 					</div>
 
 					<!-- Internal Attributes -->
-					<div class="tab-pane" id="internal" role="tabpanel">
-						@foreach ($o->getInternalAttributes() as $ao)
-							<x-attribute-type :o="$ao"/>
+					<div class="tab-pane mt-3" id="internal" role="tabpanel">
+						@foreach($o->getInternalAttributes() as $ao)
+							<x-attribute-type :o="$ao" :edit="false" :new="false" :template="$template ?? null" :updated="false"/>
 						@endforeach
 					</div>
-
-					<!-- Debug -->
-					<div class="tab-pane" id="debug" role="tabpanel">
-						<div class="row">
-							<div class="col-4">
-								@dump($o)
-							</div>
-							<div class="col-4">
-								@dump($o->getAttributes())
-							</div>
-							<div class="col-4">
-								@dump(['available'=>$o->getAvailableAttributes()->pluck('name'),'missing'=>$o->getMissingAttributes()->pluck('name')])
-							</div>
-						</div>
-					</div>
 				</div>
 			</div>
 		</div>
@@ -118,7 +147,6 @@
 @section('page-scripts')
 	<script type="text/javascript">
 		var dn = '{{ $o->getDNSecure() }}';
-		var oc = {!! $o->getObject('objectclass')->values !!};
 
 		function editmode() {
 			$('#dn-edit input[name="dn"]').val(dn);
@@ -132,7 +160,6 @@
 
 			// Find all input items and turn off readonly
 			$('input.form-control').each(function() {
-				// Except for objectClass - @todo show an "X" instead
 				if ($(this)[0].name.match(/^objectclass/))
 					return;
 
@@ -140,7 +167,7 @@
 			});
 
 			// Our password type
-			$('attribute#userPassword .form-select').each(function() {
+			$('attribute#userpassword .form-select').each(function() {
 				$(this).prop('disabled',false);
 			})
 
@@ -154,7 +181,24 @@
 		}
 
 		$(document).ready(function() {
+			$('button[id=entry-create]').on('click',function(item) {
+				location.replace('/#{{ Crypt::encryptString(sprintf('*%s|%s','create',$dn)) }}');
+				location.reload();
+			});
+
+			$('button[id=entry-edit]').on('click',function(item) {
+				item.preventDefault();
+
+				if ($(this).hasClass('btn-dark'))
+					return;
+
+				editmode();
+			});
+
 			$('#newattr').on('change',function(item) {
+				var oc = $('attribute#objectclass input[type=text]')
+					.map((key,item)=>{return $(item).val()}).toArray();
+
 				$.ajax({
 					type: 'POST',
 					beforeSend: function() {},
@@ -184,6 +228,25 @@
 				var that = $(this).find('.modal-content');
 
 				switch ($(item.relatedTarget).attr('id')) {
+					case 'entry-copy-move':
+						$.ajax({
+							method: 'GET',
+							url: '{{ url('modal/copy-move') }}/'+dn,
+							dataType: 'html',
+							cache: false,
+							beforeSend: function() {
+								that.empty().append('<span class="p-3"><i class="fas fa-3x fa-spinner fa-pulse"></i></span>');
+							},
+							success: function(data) {
+								that.empty().html(data);
+							},
+							error: function(e) {
+								if (e.status !== 412)
+									alert('That didnt work? Please try again....');
+							},
+						});
+						break;
+
 					case 'entry-delete':
 						$.ajax({
 							method: 'GET',
@@ -200,7 +263,7 @@
 								if (e.status !== 412)
 									alert('That didnt work? Please try again....');
 							},
-						})
+						});
 						break;
 
 					case 'entry-export':
@@ -240,10 +303,10 @@
 						})
 						break;
 
-					case 'entry-userpassword-check':
+					case 'entry-rename':
 						$.ajax({
 							method: 'GET',
-							url: '{{ url('modal/userpassword-check') }}/'+dn,
+							url: '{{ url('modal/rename') }}/'+dn,
 							dataType: 'html',
 							cache: false,
 							beforeSend: function() {
@@ -256,14 +319,41 @@
 								if (e.status !== 412)
 									alert('That didnt work? Please try again....');
 							},
-						})
+						});
 						break;
 
 					default:
-						console.log('No action for button:'+$(item.relatedTarget).attr('id'));
+						switch ($(item.relatedTarget).attr('name')) {
+							case 'entry-userpassword-check':
+								$.ajax({
+									method: 'GET',
+									url: '{{ url('modal/userpassword-check') }}/'+dn,
+									dataType: 'html',
+									cache: false,
+									beforeSend: function() {
+										that.empty().append('<span class="p-3"><i class="fas fa-3x fa-spinner fa-pulse"></i></span>');
+									},
+									success: function(data) {
+										that.empty().html(data);
+									},
+									error: function(e) {
+										if (e.status !== 412)
+											alert('That didnt work? Please try again....');
+									},
+								})
+								break;
+
+							default:
+								console.log('No action for button:'+$(item.relatedTarget).attr('id'));
+						}
 				}
 			});
 
+			$('#page-modal').on('hide.bs.modal',function() {
+				// Clear any select ranges that occurred while the modal was open
+				document.getSelection().removeAllRanges();
+			});
+
 			@if(old())
 				editmode();
 			@endif
