@@ -3,7 +3,7 @@
 @section('page_title')
 	<table class="table table-borderless">
 		<tr>
-			<td style="border-radius: 5px;"><div class="page-title-icon f32"><i class="fas fa-upload"></i></div></td>
+			<td><div class="page-title-icon f32"><i class="fas fa-upload"></i></div></td>
 			<td class="top text-start align-text-top p-2"><strong>@lang('LDIF Import')</strong><br><small>@lang('To Server') <strong>{{ $server->name }}</strong></small></td>
 		</tr>
 	</table>
@@ -15,7 +15,7 @@
 			<div class="main-card mb-3 card">
 				<form id="import-form" action="{{ url('import/process/ldif') }}" method="POST" enctype="multipart/form-data">
 					@csrf
-					<input type="hidden" name="key" value="{{ Crypt::encryptString('*import|_NOP') }}">
+					<input type="hidden" name="_key" value="{{ Crypt::encryptString('*import|_NOP') }}">
 
 					<div class="card-header">
 						@lang('LDIF Import')
@@ -56,7 +56,7 @@
 
 				<div class="card-footer">
 					<span class="ms-auto">
-						<x-form.submit action="Process" form="import-form"/>
+						<x-form.submit :action="__('Process')" form="import-form"/>
 					</span>
 				</div>
 			</div>
