@@ -1,19 +1,14 @@
 @extends('home')
 
 @section('page_title')
-	@include('fragment.dn.header',[
-		'langtags'=>($langtags=$o->getLangTags()
-			->flatMap(fn($item)=>$item->values())
-			->unique()
-			->sort())
-	])
+	@include('fragment.dn.header')
+@endsection
+
+@section('page_status')
+	<x-error/>
 @endsection
 
 @section('main-content')
-	<x-note/>
-	<x-success/>
-	<x-error/>
-
 	<div class="main-card mb-3 card">
 		<form id="dn-update" method="POST" class="needs-validation" action="{{ url('entry/update/commit') }}" novalidate>
 			@csrf
@@ -35,9 +30,9 @@
 							</thead>
 
 							<tbody>
-							@foreach ($o->getObjects()->filter(fn($item)=>$item->isDirty()) as $key => $oo)
+							@foreach($o->getObjects()->filter(fn($item)=>$item->isDirty()) as $key => $oo)
 								<tr>
-									<th rowspan="{{ $x=max($oo->values->dot()->keys()->count(),$oo->values_old->dot()->keys()->count())+1}}">
+									<th rowspan="{{ $x=max($oo->values->dot()->keys()->count(),$oo->values_old->dot()->keys()->count())}}">
 										<abbr title="{{ $oo->description }}">{{ $oo->name }}</abbr>
 									</th>
 
@@ -54,7 +49,7 @@
 											<td colspan="2" class="text-center">@lang('Ignoring blank value')</td>
 										@else
 											<td>{{ (($r=$oo->render_item_old($dotkey)) !== NULL) ? $r : '['.strtoupper(__('New Value')).']' }}</td>
-											<td>{{ (($r=$oo->render_item_new($dotkey)) !== NULL) ? $r : '['.strtoupper(__('Deleted')).']' }}<input type="hidden" name="{{ $key }}[{{ collect(explode('.',$dotkey))->first() }}][]" value="{{ Arr::get($oo,$dotkey) }}"></td>
+											<td>{{ (($r=$oo->render_item_new($dotkey)) !== NULL) ? $r : '['.strtoupper(__('Deleted')).']' }}<input type="hidden" name="{{ $key }}[{{ $oo->no_attr_tags ? \App\Ldap\Entry::TAG_NOTAG : collect(explode('.',$dotkey))->first() }}][]" value="{{ Arr::get($oo->values->dot(),$dotkey) }}"></td>
 										@endif
 									@endforeach
 								</tr>
@@ -69,7 +64,7 @@
 		<div class="row p-3">
 			<div class="col-12 offset-sm-2 col-sm-4 col-lg-2 mx-auto">
 				<x-form.cancel/>
-				<x-form.submit action="Update" form="dn-update"/>
+				<x-form.submit :action="__('Update')" form="dn-update"/>
 			</div>
 		</div>
 
